From 20a3c3da3869751ecacd306e267c53059a5f7973 Mon Sep 17 00:00:00 2001
From: Josh Soref <2119212+jsoref@users.noreply.github.com>
Date: Mon, 18 Jul 2022 07:59:03 -0400
Subject: [PATCH] Spelling (#5885)
---
CONTRIBUTING.md | 2 +-
README.md | 2 +-
src/etc/inc/config.inc | 2 +-
src/etc/inc/filter.lib.inc | 4 ++--
src/etc/inc/interfaces.inc | 4 ++--
src/etc/inc/interfaces.lib.inc | 2 +-
src/etc/inc/plugins.inc.d/dhcpd.inc | 2 +-
src/etc/inc/plugins.inc.d/dpinger.inc | 2 +-
src/etc/inc/plugins.inc.d/loopback.inc | 2 +-
src/etc/inc/plugins.inc.d/openvpn.inc | 4 ++--
src/etc/inc/plugins.inc.d/vxlan.inc | 2 +-
src/etc/inc/plugins.inc.d/webgui.inc | 6 +++---
src/etc/inc/xmlrpc/legacy.inc | 2 +-
src/etc/rc.filter_synchronize | 2 +-
src/etc/rc.newwanipv6 | 2 +-
src/etc/rc.subr.d/var | 2 +-
src/etc/ssl/opnsense.cnf | 6 +++---
src/man/man8/opnsense-version.8 | 2 +-
src/opnsense/mvc/app/config/services.php | 2 +-
src/opnsense/mvc/app/config/services_api.php | 2 +-
.../CaptivePortal/Api/AccessController.php | 2 +-
.../OPNsense/Core/Api/FirmwareController.php | 14 +++++++-------
.../OPNsense/Diagnostics/Api/NetflowController.php | 2 +-
.../OPNsense/Firewall/Api/AliasUtilController.php | 2 +-
.../OPNsense/IPsec/Api/SadController.php | 2 +-
.../OPNsense/IPsec/Api/SpdController.php | 2 +-
.../OPNsense/IPsec/Api/TunnelController.php | 4 ++--
.../OPNsense/OpenVPN/Api/ExportController.php | 4 ++--
.../app/controllers/OPNsense/Proxy/forms/main.xml | 2 +-
.../TrafficShaper/Api/ServiceController.php | 2 +-
.../OPNsense/TrafficShaper/forms/dialogPipe.xml | 6 +++---
.../OPNsense/TrafficShaper/forms/dialogQueue.xml | 4 ++--
.../mvc/app/library/OPNsense/Auth/IService.php | 4 ++--
.../mvc/app/library/OPNsense/Core/Config.php | 4 ++--
.../mvc/app/library/OPNsense/Firewall/Util.php | 2 +-
.../mvc/app/library/OPNsense/Routing/Gateways.php | 4 ++--
.../mvc/app/models/OPNsense/Base/BaseModel.php | 6 +++---
.../Base/Constraints/ComparedToFieldConstraint.php | 6 +++---
.../OPNsense/Base/Constraints/SetIfConstraint.php | 2 +-
.../models/OPNsense/Base/FieldTypes/BaseField.php | 2 +-
.../OPNsense/Base/FieldTypes/LegacyLinkField.php | 2 +-
.../mvc/app/models/OPNsense/Core/ACL/ACL.php | 2 +-
.../mvc/app/models/OPNsense/Firewall/Category.php | 2 +-
.../mvc/app/models/OPNsense/Monit/Monit.php | 12 ++++++------
.../mvc/app/models/OPNsense/Monit/Monit.xml | 2 +-
.../OPNsense/TrafficShaper/TrafficShaper.php | 2 +-
.../mvc/app/views/OPNsense/Diagnostics/log.volt | 2 +-
.../app/views/OPNsense/Diagnostics/netflow.volt | 2 +-
.../views/OPNsense/Diagnostics/systemhealth.volt | 10 +++++-----
.../mvc/app/views/OPNsense/Firewall/alias.volt | 2 +-
.../app/views/OPNsense/Firewall/alias_util.volt | 2 +-
src/opnsense/mvc/app/views/layouts/default.volt | 2 +-
.../Constraints/ComparedToFieldConstraintTest.php | 4 ++--
.../Base/FieldTypes/ModelRelationFieldTest.php | 4 ++--
.../CaptivePortal/cp-background-process.py | 4 ++--
.../scripts/OPNsense/CaptivePortal/lib/__init__.py | 2 +-
.../scripts/OPNsense/CaptivePortal/lib/ipfw.py | 2 +-
src/opnsense/scripts/dhcp/dnsmasq_watcher.py | 2 +-
src/opnsense/scripts/dhcp/unbound_watcher.py | 2 +-
src/opnsense/scripts/filter/read_log.py | 2 +-
src/opnsense/scripts/firmware/check.sh | 2 +-
src/opnsense/scripts/interfaces/mpd.script | 6 +++---
src/opnsense/scripts/interfaces/traffic_top.py | 4 ++--
.../scripts/netflow/lib/aggregates/__init__.py | 2 +-
.../scripts/netflow/lib/aggregates/interface.py | 2 +-
.../scripts/netflow/lib/aggregates/ports.py | 2 +-
.../scripts/netflow/lib/aggregates/source.py | 2 +-
src/opnsense/scripts/proxy/fetchACLs.py | 2 +-
src/opnsense/scripts/shell/firmware.sh | 2 +-
src/opnsense/scripts/suricata/installRules.py | 2 +-
src/opnsense/scripts/suricata/lib/rulecache.py | 2 +-
.../service/modules/addons/template_helpers.py | 2 +-
src/opnsense/service/modules/template.py | 2 +-
.../Captiveportal/lighttpd-api-dispatcher.conf | 2 +-
.../service/templates/OPNsense/IDS/suricata.yaml | 10 +++++-----
.../service/templates/OPNsense/Proxy/squid.conf | 6 +++---
src/opnsense/www/api.php | 2 +-
src/opnsense/www/js/opnsense.js | 2 +-
.../stylesheets/bootstrap/_input-groups.scss | 2 +-
.../stylesheets/bootstrap/mixins/_hide-text.scss | 2 +-
src/sbin/ping_hosts.sh | 2 +-
src/wizard/system.xml | 2 +-
src/www/firewall_schedule_edit.php | 8 ++++----
src/www/guiconfig.inc | 4 ++--
src/www/interfaces.php | 8 ++++----
src/www/javascript/opnsense_legacy.js | 2 +-
src/www/services_dhcp.php | 2 +-
src/www/services_dhcpv6.php | 2 +-
src/www/services_router_advertisements.php | 2 +-
src/www/status_interfaces.php | 12 ++++++------
src/www/system_advanced_admin.php | 2 +-
src/www/system_certmanager.php | 6 +++---
src/www/system_general.php | 2 +-
src/www/system_usermanager.php | 2 +-
src/www/vpn_ipsec_phase2.php | 2 +-
src/www/vpn_openvpn_client.php | 2 +-
src/www/vpn_openvpn_server.php | 4 ++--
src/www/widgets/widgets/gateways.widget.php | 6 +++---
src/www/widgets/widgets/ntp_status.widget.php | 2 +-
99 files changed, 162 insertions(+), 162 deletions(-)
diff --git a/CONTRIBUTING.md b/CONTRIBUTING.md
index 7f3b80ebd..9f709a05d 100644
--- a/CONTRIBUTING.md
+++ b/CONTRIBUTING.md
@@ -25,7 +25,7 @@ All issues reported will have to be triaged and prioritised. As we
are a small team we may not always have the time to implement and help,
but reporting an issue may help others to fill in.
-The issue catetories are as follows:
+The issue categories are as follows:
* support: community-based help figuring out setup issues or code problems
* cleanup: cosmetic changes or non-operational bugs (display issues, etc.)
diff --git a/README.md b/README.md
index 280346026..88db14001 100644
--- a/README.md
+++ b/README.md
@@ -94,7 +94,7 @@ Fetch changes from the running system for all known files.
make lint
---------
-Run serveral syntax checks on the repository. This is recommended
+Run several syntax checks on the repository. This is recommended
before issuing a pull request on GitHub.
make style
diff --git a/src/etc/inc/config.inc b/src/etc/inc/config.inc
index cc3469c65..bc12003b4 100644
--- a/src/etc/inc/config.inc
+++ b/src/etc/inc/config.inc
@@ -163,7 +163,7 @@ function write_config($desc = '', $backup = true)
return -1;
}
- /* on succesfull save, serialize config back to global */
+ /* on successful save, serialize config back to global */
$config = $cnf->toArray(listtags());
return $config;
diff --git a/src/etc/inc/filter.lib.inc b/src/etc/inc/filter.lib.inc
index 4d14eb3c7..5f700842a 100644
--- a/src/etc/inc/filter.lib.inc
+++ b/src/etc/inc/filter.lib.inc
@@ -266,12 +266,12 @@ function filter_core_rules_system($fw, $defaults)
'to' => 'ff02::/16', 'direction' => 'in' ),
$defaults['pass']
);
- // block all targetting port 0
+ // block all targeting port 0
foreach (array('from_port', 'to_port') as $target) {
$fw->registerFilterRule(
1,
array('ipprotocol' => 'inet46', 'protocol' => 'tcp/udp', $target => '0',
- 'descr' => 'block all targetting port 0'),
+ 'descr' => 'block all targeting port 0'),
$defaults['block']
);
}
diff --git a/src/etc/inc/interfaces.inc b/src/etc/inc/interfaces.inc
index 8030d1f84..831eaf19d 100644
--- a/src/etc/inc/interfaces.inc
+++ b/src/etc/inc/interfaces.inc
@@ -209,7 +209,7 @@ function _interfaces_vlan_configure($vlan)
{
interfaces_bring_up($vlan['if']); /* XXX overreach? */
- /* destroy is a safety precaution, when confguring via api or gui this function should only be called on new vlans */
+ /* destroy is a safety precaution, when configuring via api or gui this function should only be called on new vlans */
legacy_interface_destroy($vlan['vlanif']);
legacy_interface_create('vlan', $vlan['vlanif']);
@@ -1709,7 +1709,7 @@ function interface_wireless_configure($if, &$wancfg)
$wlcmd[] = "-mediaopt adhoc";
}
- /* Not neccesary to set BSS mode as this is default if adhoc and/or hostap is NOT set */
+ /* Not necessary to set BSS mode as this is default if adhoc and/or hostap is NOT set */
/* handle hide ssid option */
if (isset($wlcfg['hidessid']['enable'])) {
diff --git a/src/etc/inc/interfaces.lib.inc b/src/etc/inc/interfaces.lib.inc
index 90d769b6d..68274add2 100644
--- a/src/etc/inc/interfaces.lib.inc
+++ b/src/etc/inc/interfaces.lib.inc
@@ -234,7 +234,7 @@ function legacy_interfaces_details($intf = null)
$cmd = '/sbin/ifconfig -m -v ' . $tmp_intf;
exec($cmd . ' 2>&1', $ifconfig_data, $ret);
if ($ret) {
- /* only error if no explicit interface was choosen */
+ /* only error if no explicit interface was chosen */
if (empty($intf)) {
log_error('The command `' . $cmd . '\' failed to execute ' . implode(' ', $ifconfig_data));
}
diff --git a/src/etc/inc/plugins.inc.d/dhcpd.inc b/src/etc/inc/plugins.inc.d/dhcpd.inc
index f29a87892..21587b520 100644
--- a/src/etc/inc/plugins.inc.d/dhcpd.inc
+++ b/src/etc/inc/plugins.inc.d/dhcpd.inc
@@ -1863,7 +1863,7 @@ function dhcpd_staticmap($domain_fallback = 'not.found', $ifconfig_details = nul
}
// XXX: dhcpdv6 domain entries have been superseded by domainsearchlist,
- // for backward compatibilty support both here.
+ // for backward compatibility support both here.
if ($inet == 6 && !empty($host['domainsearchlist'])) {
$domain = $host['domainsearchlist'];
} elseif (!empty($host['domain'])) {
diff --git a/src/etc/inc/plugins.inc.d/dpinger.inc b/src/etc/inc/plugins.inc.d/dpinger.inc
index bc834d2c4..75420941d 100644
--- a/src/etc/inc/plugins.inc.d/dpinger.inc
+++ b/src/etc/inc/plugins.inc.d/dpinger.inc
@@ -133,7 +133,7 @@ function dpinger_configure_do($verbose = false, $gwname = null, $bootup = false)
if (is_ipaddrv4($gateway['gateway'])) {
foreach (interfaces_addresses($gateway['interface'], false, $ifconfig_details) as $addr) {
- /* explictly do not require $addr['alias'] to be true here */
+ /* explicitly do not require $addr['alias'] to be true here */
if ($addr['family'] != 'inet') {
continue;
}
diff --git a/src/etc/inc/plugins.inc.d/loopback.inc b/src/etc/inc/plugins.inc.d/loopback.inc
index bcaf74ed8..39e3f531a 100644
--- a/src/etc/inc/plugins.inc.d/loopback.inc
+++ b/src/etc/inc/plugins.inc.d/loopback.inc
@@ -94,7 +94,7 @@ function loopback_configure_do($verbose = false, $device = null)
}
}
- // destroy non existing interfaces
+ // destroy nonexistent interfaces
foreach ($configured_interfaces as $intf) {
if (strpos($intf, "lo") === 0) {
if (!in_array($intf, $configured_devices)) {
diff --git a/src/etc/inc/plugins.inc.d/openvpn.inc b/src/etc/inc/plugins.inc.d/openvpn.inc
index b17d85dfc..e73c0150f 100644
--- a/src/etc/inc/plugins.inc.d/openvpn.inc
+++ b/src/etc/inc/plugins.inc.d/openvpn.inc
@@ -497,7 +497,7 @@ function openvpn_reconfigure($mode, $settings, $device_only = false)
* If a specific IP address (VIP) is requested, use it.
* Otherwise, if a specific interface is requested, use
* it unless "any" interface was selected, then the local
- * directive will be ommited.
+ * directive will be omitted.
*/
if (is_ipaddr($settings['ipaddr'])) {
$iface_ip = $settings['ipaddr'];
@@ -972,7 +972,7 @@ function openvpn_delete($mode, &$settings)
* generate config (text) data for a single client specific override
* @param array $settings csc item
* @param array $server openvpn server item
- * @param string $target_filename write to filename, or use configured/generated path when emtpy
+ * @param string $target_filename write to filename, or use configured/generated path when empty
* @return string|boolean filename or false when unable to (missing common name or vpnid)
*/
function openvpn_csc_conf_write($settings, $server, $target_filename = null)
diff --git a/src/etc/inc/plugins.inc.d/vxlan.inc b/src/etc/inc/plugins.inc.d/vxlan.inc
index 3ef2069e5..51f6f1d42 100644
--- a/src/etc/inc/plugins.inc.d/vxlan.inc
+++ b/src/etc/inc/plugins.inc.d/vxlan.inc
@@ -136,7 +136,7 @@ function vxlan_configure_do($verbose = false, $device = null)
}
}
- // destroy non existing interfaces
+ // destroy nonexistent interfaces
foreach ($interfaces_details as $intf => $data) {
if (strpos($intf, "vxlan") === 0) {
if (!in_array($intf, $configured_devices)) {
diff --git a/src/etc/inc/plugins.inc.d/webgui.inc b/src/etc/inc/plugins.inc.d/webgui.inc
index 0086a6f54..4ce62809c 100644
--- a/src/etc/inc/plugins.inc.d/webgui.inc
+++ b/src/etc/inc/plugins.inc.d/webgui.inc
@@ -100,7 +100,7 @@ function webgui_configure_do($verbose = false, $interface = '')
if ($config['system']['webgui']['protocol'] == "https") {
$cert =& lookup_cert($config['system']['webgui']['ssl-certref']);
if (!is_array($cert) && !$cert['crt'] && !$cert['prv']) {
- /* XXX for now only if a certificate is not availabe */
+ /* XXX for now only if a certificate is not available */
webgui_create_selfsigned(false);
$cert =& lookup_cert($config['system']['webgui']['ssl-certref']);
}
@@ -139,7 +139,7 @@ function webgui_configure_do($verbose = false, $interface = '')
*/
killbyname('php-cgi', 'HUP');
- /* start lighthttpd */
+ /* start lighttpd */
if (!count($listeners) || mwexec('/usr/local/sbin/lighttpd -f /var/etc/lighty-webConfigurator.conf')) {
if ($verbose) {
echo "failed.\n";
@@ -361,7 +361,7 @@ mimetype.assign = (
url.access-deny = ( "~", ".inc" )
-######### Options that are good to be but not neccesary to be changed #######
+######### Options that are good to be but not necessary to be changed #######
## bind to port (default: 80)
diff --git a/src/etc/inc/xmlrpc/legacy.inc b/src/etc/inc/xmlrpc/legacy.inc
index 7182b68f2..a1eaa119d 100644
--- a/src/etc/inc/xmlrpc/legacy.inc
+++ b/src/etc/inc/xmlrpc/legacy.inc
@@ -147,7 +147,7 @@ function restore_config_section_xmlrpc($new_config)
$old_config = $config;
// Some sections should just be copied and not merged, namely if there's a risk of attributes being removed
- // without being seen by the remote remote (backup) side.
+ // without being seen by the remote (backup) side.
// (ipsec, openvpn, nat can probably moved out later by specifying a better path to the attribute)
$sync_full = array('ipsec', 'wol', 'dnsmasq', 'load_balancer', 'openvpn', 'nat', 'dhcpd', 'dhcpv6');
$sync_full_done = array();
diff --git a/src/etc/rc.filter_synchronize b/src/etc/rc.filter_synchronize
index 124289ce4..b1146d06a 100755
--- a/src/etc/rc.filter_synchronize
+++ b/src/etc/rc.filter_synchronize
@@ -181,7 +181,7 @@ function carp_sync_xml($url, $username, $password, $sections, $debug)
// remove items which may not be synced
remove_nosync($transport_data);
- // ***** post proccessing *****
+ // ***** post processing *****
// dhcpd, unchanged from legacy code (may need some inspection later)
if (is_array($transport_data['dhcpd'])) {
foreach($transport_data['dhcpd'] as $dhcpif => $dhcpifconf) {
diff --git a/src/etc/rc.newwanipv6 b/src/etc/rc.newwanipv6
index 45c487060..23c1db2a0 100755
--- a/src/etc/rc.newwanipv6
+++ b/src/etc/rc.newwanipv6
@@ -80,7 +80,7 @@ system_resolvconf_generate();
system_hosts_generate();
if ($config['interfaces'][$interface]['ipaddrv6'] == 'slaac') {
- /* require immediate recofiguration before reconfiguring clients */
+ /* require immediate reconfiguration before reconfiguring clients */
plugins_configure('dhcp', false, ['inet6']);
}
diff --git a/src/etc/rc.subr.d/var b/src/etc/rc.subr.d/var
index ce7a9a4fa..d2c4e6eeb 100755
--- a/src/etc/rc.subr.d/var
+++ b/src/etc/rc.subr.d/var
@@ -100,7 +100,7 @@ else
chmod 755 /root # XXX 750 when ready
fi
-# XXX remove all renmants of /root/var handling after 22.7
+# XXX remove all remnants of /root/var handling after 22.7
for DIR in ${MFS_DIRS}; do
# unconditionally remove old /var links now that the
# feature is constrained to /var/log directory
diff --git a/src/etc/ssl/opnsense.cnf b/src/etc/ssl/opnsense.cnf
index 5aaccb867..d75a70eda 100644
--- a/src/etc/ssl/opnsense.cnf
+++ b/src/etc/ssl/opnsense.cnf
@@ -45,7 +45,7 @@ certs = $dir/certs # Where the issued certs are kept
crl_dir = $dir/crl # Where the issued crl are kept
database = $dir/index.txt # database index file.
#unique_subject = no # Set to 'no' to allow creation of
- # several ctificates with same subject.
+ # several certificates with same subject.
new_certs_dir = $dir/newcerts # default place for new certs.
certificate = $dir/cacert.pem # The CA certificate
@@ -56,7 +56,7 @@ crl = $dir/crl.pem # The current CRL
private_key = $dir/private/cakey.pem# The private key
RANDFILE = $dir/private/.rand # private random number file
-x509_extensions = usr_cert # The extentions to add to the cert
+x509_extensions = usr_cert # The extensions to add to the cert
# Comment out the following two lines for the "traditional"
# (and highly broken) format.
@@ -108,7 +108,7 @@ default_bits = 1024
default_keyfile = privkey.pem
distinguished_name = req_distinguished_name
attributes = req_attributes
-x509_extensions = v3_ca # The extentions to add to the self signed cert
+x509_extensions = v3_ca # The extensions to add to the self signed cert
# Passwords for private keys if not present they will be prompted for
# input_password = secret
diff --git a/src/man/man8/opnsense-version.8 b/src/man/man8/opnsense-version.8
index d0ff0e38c..429b4b6f5 100644
--- a/src/man/man8/opnsense-version.8
+++ b/src/man/man8/opnsense-version.8
@@ -53,7 +53,7 @@ parameter, but not intended to handle operating system information.
.Pp
The default package is assumed to be
.Ar core ,
-unless another package has been specificed.
+unless another package has been specified.
Other packages can be
.Ar base ,
.Ar kernel ,
diff --git a/src/opnsense/mvc/app/config/services.php b/src/opnsense/mvc/app/config/services.php
index ac0b27e90..7cbbeb6a0 100644
--- a/src/opnsense/mvc/app/config/services.php
+++ b/src/opnsense/mvc/app/config/services.php
@@ -83,7 +83,7 @@ $di->setShared('session', function () {
]);
$session->setAdapter($files);
$session->start();
- // Set session response cookie, unfortunalty we need to read the config here to determine if secure option is
+ // Set session response cookie, unfortunately we need to read the config here to determine if secure option is
// a valid choice.
$cnf = Config::getInstance();
if ((string)$cnf->object()->system->webgui->protocol == 'https') {
diff --git a/src/opnsense/mvc/app/config/services_api.php b/src/opnsense/mvc/app/config/services_api.php
index 9638234c6..4506a0507 100644
--- a/src/opnsense/mvc/app/config/services_api.php
+++ b/src/opnsense/mvc/app/config/services_api.php
@@ -70,7 +70,7 @@ $di->setShared('session', function () {
]);
$session->setAdapter($files);
$session->start();
- // Set session response cookie, unfortunalty we need to read the config here to determine if secure option is
+ // Set session response cookie, unfortunately we need to read the config here to determine if secure option is
// a valid choice.
$cnf = Config::getInstance();
if ((string)$cnf->object()->system->webgui->protocol == 'https') {
diff --git a/src/opnsense/mvc/app/controllers/OPNsense/CaptivePortal/Api/AccessController.php b/src/opnsense/mvc/app/controllers/OPNsense/CaptivePortal/Api/AccessController.php
index 623de1e49..8bd41ed06 100644
--- a/src/opnsense/mvc/app/controllers/OPNsense/CaptivePortal/Api/AccessController.php
+++ b/src/opnsense/mvc/app/controllers/OPNsense/CaptivePortal/Api/AccessController.php
@@ -92,7 +92,7 @@ class AccessController extends ApiControllerBase
*/
private function getClientIp()
{
- // determine orginal sender of this request
+ // determine original sender of this request
if (
$this->request->getHeader('X-Forwarded-For') != "" &&
explode('.', $this->request->getClientAddress())[0] == '127'
diff --git a/src/opnsense/mvc/app/controllers/OPNsense/Core/Api/FirmwareController.php b/src/opnsense/mvc/app/controllers/OPNsense/Core/Api/FirmwareController.php
index 1fab2cf16..66c1b861f 100644
--- a/src/opnsense/mvc/app/controllers/OPNsense/Core/Api/FirmwareController.php
+++ b/src/opnsense/mvc/app/controllers/OPNsense/Core/Api/FirmwareController.php
@@ -139,19 +139,19 @@ class FirmwareController extends ApiControllerBase
switch (isset($matches[2]) ? strtolower($matches[2]) : 'b') {
case 'p':
$factor *= 1024;
- /* FALLTROUGH */
+ /* FALLTHROUGH */
case 't':
$factor *= 1024;
- /* FALLTROUGH */
+ /* FALLTHROUGH */
case 'g':
$factor *= 1024;
- /* FALLTROUGH */
+ /* FALLTHROUGH */
case 'm':
$factor *= 1024;
- /* FALLTROUGH */
+ /* FALLTHROUGH */
case 'k':
$factor *= 1024;
- /* FALLTROUGH */
+ /* FALLTHROUGH */
default:
break;
}
@@ -338,7 +338,7 @@ class FirmwareController extends ApiControllerBase
/**
* Retrieve specific changelog in text and html format
* @param string $version changelog to retrieve
- * @return array correspondng changelog in both formats
+ * @return array corresponding changelog in both formats
* @throws \Exception
*/
public function changelogAction($version)
@@ -758,7 +758,7 @@ class FirmwareController extends ApiControllerBase
}
/**
- * retrieve exectution status
+ * retrieve execution status
*/
public function runningAction()
{
diff --git a/src/opnsense/mvc/app/controllers/OPNsense/Diagnostics/Api/NetflowController.php b/src/opnsense/mvc/app/controllers/OPNsense/Diagnostics/Api/NetflowController.php
index 3553b9b05..7b6edf258 100644
--- a/src/opnsense/mvc/app/controllers/OPNsense/Diagnostics/Api/NetflowController.php
+++ b/src/opnsense/mvc/app/controllers/OPNsense/Diagnostics/Api/NetflowController.php
@@ -140,7 +140,7 @@ class NetflowController extends ApiControllerBase
// aggregation process maybe restarted at all time
$backend->configdRun("netflow aggregate restart");
} else {
- // stop collector and agreggator
+ // stop collector and aggregator
$backend->configdRun("netflow collect stop");
$backend->configdRun("netflow aggregate stop");
}
diff --git a/src/opnsense/mvc/app/controllers/OPNsense/Firewall/Api/AliasUtilController.php b/src/opnsense/mvc/app/controllers/OPNsense/Firewall/Api/AliasUtilController.php
index 9179e710d..be322278b 100644
--- a/src/opnsense/mvc/app/controllers/OPNsense/Firewall/Api/AliasUtilController.php
+++ b/src/opnsense/mvc/app/controllers/OPNsense/Firewall/Api/AliasUtilController.php
@@ -255,7 +255,7 @@ class AliasUtilController extends ApiControllerBase
$backend->configdpRun("filter add table", array($alias, $address));
return array("status" => "done");
} else {
- return array("status" => "failed", "status_msg" => sprintf("non existing alias %s", $alias));
+ return array("status" => "failed", "status_msg" => sprintf("nonexistent alias %s", $alias));
}
} else {
return array("status" => "failed");
diff --git a/src/opnsense/mvc/app/controllers/OPNsense/IPsec/Api/SadController.php b/src/opnsense/mvc/app/controllers/OPNsense/IPsec/Api/SadController.php
index ef6396ff9..a60da53ea 100644
--- a/src/opnsense/mvc/app/controllers/OPNsense/IPsec/Api/SadController.php
+++ b/src/opnsense/mvc/app/controllers/OPNsense/IPsec/Api/SadController.php
@@ -39,7 +39,7 @@ use OPNsense\Core\Config;
class SadController extends ApiControllerBase
{
/**
- * Search SAD entrys
+ * Search SAD entries
* @return array
*/
public function searchAction()
diff --git a/src/opnsense/mvc/app/controllers/OPNsense/IPsec/Api/SpdController.php b/src/opnsense/mvc/app/controllers/OPNsense/IPsec/Api/SpdController.php
index b44508dc0..ad461e0fe 100644
--- a/src/opnsense/mvc/app/controllers/OPNsense/IPsec/Api/SpdController.php
+++ b/src/opnsense/mvc/app/controllers/OPNsense/IPsec/Api/SpdController.php
@@ -39,7 +39,7 @@ use OPNsense\Core\Config;
class SpdController extends ApiControllerBase
{
/**
- * Search SPD entrys
+ * Search SPD entries
* @return array
*/
public function searchAction()
diff --git a/src/opnsense/mvc/app/controllers/OPNsense/IPsec/Api/TunnelController.php b/src/opnsense/mvc/app/controllers/OPNsense/IPsec/Api/TunnelController.php
index fb9643ea8..b8232a3d0 100644
--- a/src/opnsense/mvc/app/controllers/OPNsense/IPsec/Api/TunnelController.php
+++ b/src/opnsense/mvc/app/controllers/OPNsense/IPsec/Api/TunnelController.php
@@ -54,7 +54,7 @@ class TunnelController extends ApiControllerBase
'cast128' => 'CAST128',
'des' => 'DES'
];
- $ph1authmethos = [
+ $ph1authmethods = [
'hybrid_rsa_server' => 'Hybrid RSA + Xauth',
'xauth_rsa_server' => 'Mutual RSA + Xauth',
'xauth_psk_server' => 'Mutual PSK + Xauth',
@@ -109,7 +109,7 @@ class TunnelController extends ApiControllerBase
"mobile" => !empty((string)$p1->mobile),
"mode" => (string)$p1->mode,
"proposal" => $ph1proposal,
- "authentication" => $ph1authmethos[(string)$p1->authentication_method],
+ "authentication" => $ph1authmethods[(string)$p1->authentication_method],
"description" => (string)$p1->descr
];
$item['type'] = "{$item['protocol']} {$item['iketype']}";
diff --git a/src/opnsense/mvc/app/controllers/OPNsense/OpenVPN/Api/ExportController.php b/src/opnsense/mvc/app/controllers/OPNsense/OpenVPN/Api/ExportController.php
index 5d4144baa..098822ac1 100644
--- a/src/opnsense/mvc/app/controllers/OPNsense/OpenVPN/Api/ExportController.php
+++ b/src/opnsense/mvc/app/controllers/OPNsense/OpenVPN/Api/ExportController.php
@@ -127,7 +127,7 @@ class ExportController extends ApiControllerBase
* @return array
* @throws \OPNsense\Base\ModelException when unable to create model
*/
- private function configuredSetttings($vpnid)
+ private function configuredSettings($vpnid)
{
$result = array();
$serverModel = $this->getModel()->getServer($vpnid);
@@ -191,7 +191,7 @@ class ExportController extends ApiControllerBase
// relevant properties
$result[$vpnid]["mode"] = (string)$server->mode;
$result[$vpnid]["vpnid"] = $vpnid;
- $result[$vpnid] = array_merge($result[$vpnid], $this->configuredSetttings($vpnid));
+ $result[$vpnid] = array_merge($result[$vpnid], $this->configuredSettings($vpnid));
}
return $result;
}
diff --git a/src/opnsense/mvc/app/controllers/OPNsense/Proxy/forms/main.xml b/src/opnsense/mvc/app/controllers/OPNsense/Proxy/forms/main.xml
index 4677be88a..018b1a374 100644
--- a/src/opnsense/mvc/app/controllers/OPNsense/Proxy/forms/main.xml
+++ b/src/opnsense/mvc/app/controllers/OPNsense/Proxy/forms/main.xml
@@ -232,7 +232,7 @@
proxy.general.traffic.OverallBandwidthTrottelingtext
- Enter the allowed overall bandtwith in kilobits per second (leave empty to disable).
+ Enter the allowed overall bandwidth in kilobits per second (leave empty to disable).proxy.general.traffic.perHostTrotteling
diff --git a/src/opnsense/mvc/app/controllers/OPNsense/TrafficShaper/Api/ServiceController.php b/src/opnsense/mvc/app/controllers/OPNsense/TrafficShaper/Api/ServiceController.php
index cb5292856..b6d74d88e 100644
--- a/src/opnsense/mvc/app/controllers/OPNsense/TrafficShaper/Api/ServiceController.php
+++ b/src/opnsense/mvc/app/controllers/OPNsense/TrafficShaper/Api/ServiceController.php
@@ -93,7 +93,7 @@ class ServiceController extends ApiControllerBase
$this->sessionClose();
$ipfwstats = json_decode((new Backend())->configdRun("ipfw stats"), true);
if ($ipfwstats != null) {
- // ipfw stats are stuctured as they would be using the various ipfw commands, let's reformat
+ // ipfw stats are structured as they would be using the various ipfw commands, let's reformat
// into something easier to handle from the UI and attach model data.
$result['status'] = "ok";
$result['items'] = array();
diff --git a/src/opnsense/mvc/app/controllers/OPNsense/TrafficShaper/forms/dialogPipe.xml b/src/opnsense/mvc/app/controllers/OPNsense/TrafficShaper/forms/dialogPipe.xml
index bc4ca5041..4ae5b6d49 100644
--- a/src/opnsense/mvc/app/controllers/OPNsense/TrafficShaper/forms/dialogPipe.xml
+++ b/src/opnsense/mvc/app/controllers/OPNsense/TrafficShaper/forms/dialogPipe.xml
@@ -28,9 +28,9 @@
dropdownChoose destination to give every IP in destination field of rules the specified bandwith. A pipe with 1Mbit e.g. would let 3 clients lend 1Mbit each so 3Mbit max. Normally this is used for download pipes.
-
Choose source to give every IP in the source field of rules the specified bandwith. Normally this is used for upload pipes.
-
Leave this value empty if you want to create a pipe with a fixed bandwith.
+
Choose destination to give every IP in destination field of rules the specified bandwidth. A pipe with 1Mbit e.g. would let 3 clients lend 1Mbit each so 3Mbit max. Normally this is used for download pipes.
+
Choose source to give every IP in the source field of rules the specified bandwidth. Normally this is used for upload pipes.
+
Leave this value empty if you want to create a pipe with a fixed bandwidth.
]]>
diff --git a/src/opnsense/mvc/app/controllers/OPNsense/TrafficShaper/forms/dialogQueue.xml b/src/opnsense/mvc/app/controllers/OPNsense/TrafficShaper/forms/dialogQueue.xml
index 853a3b09c..fff2c1215 100644
--- a/src/opnsense/mvc/app/controllers/OPNsense/TrafficShaper/forms/dialogQueue.xml
+++ b/src/opnsense/mvc/app/controllers/OPNsense/TrafficShaper/forms/dialogQueue.xml
@@ -22,8 +22,8 @@
dropdownChoose destination to evenly share every IP in destination field of rules the specified bandwith. A pipe with 1Mbit e.g. would let 4 clients lend 250Kbit each. Normally this is used for download queues.
-
Choose source to evenly share every IP in the source field of rules the specified bandwith. Normally this is used for upload queues.
+
Choose destination to evenly share every IP in destination field of rules the specified bandwidth. A pipe with 1Mbit e.g. would let 4 clients lend 250Kbit each. Normally this is used for download queues.
+
Choose source to evenly share every IP in the source field of rules the specified bandwidth. Normally this is used for upload queues.
Leave this value empty if you want to specify multiple queues with different weights.
]]>
diff --git a/src/opnsense/mvc/app/library/OPNsense/Auth/IService.php b/src/opnsense/mvc/app/library/OPNsense/Auth/IService.php
index a39bef93c..2f595a2fa 100644
--- a/src/opnsense/mvc/app/library/OPNsense/Auth/IService.php
+++ b/src/opnsense/mvc/app/library/OPNsense/Auth/IService.php
@@ -53,7 +53,7 @@ interface IService
public function supportedAuthenticators();
/**
- * set the username for this service, in some scenarios this might be prefixed with some addtional
+ * set the username for this service, in some scenarios this might be prefixed with some additional
* logic to determine which authenticators are actually supported.
* (in case one pam service has multiple real services assigned)
* @param $username string
@@ -68,7 +68,7 @@ interface IService
/**
* When authenticated, validate if this user is actually allowed to access the service, there might be
- * other constraints, such as required gropu memberships.
+ * other constraints, such as required group memberships.
* @return boolean is authenticated
*/
public function checkConstraints();
diff --git a/src/opnsense/mvc/app/library/OPNsense/Core/Config.php b/src/opnsense/mvc/app/library/OPNsense/Core/Config.php
index e925b016b..66c2bc85f 100644
--- a/src/opnsense/mvc/app/library/OPNsense/Core/Config.php
+++ b/src/opnsense/mvc/app/library/OPNsense/Core/Config.php
@@ -530,7 +530,7 @@ class Config extends Singleton
if (file_exists($target_dir . "config-" . $timestamp . ".xml")) {
// The new target backup filename shouldn't exists, because of the use of microtime.
// in the unlikely event that we can process events too fast for microtime(), suffix with a more
- // precise tiestamp to ensure we can't miss a backup
+ // precise timestamp to ensure we can't miss a backup
$target_filename = "config-" . $timestamp . "_" . hrtime()[1] . ".xml";
} else {
$target_filename = "config-" . $timestamp . ".xml";
@@ -679,7 +679,7 @@ class Config extends Singleton
if ($backup_filename) {
$this->auditLogChange($backup_filename, $revision);
// use syslog to trigger a new configd event, which should signal a syshook config (in batch).
- // Althought we include the backup filename, the event handler is responsible to determine the
+ // Although we include the backup filename, the event handler is responsible to determine the
// last processed event itself. (it's merely added for debug purposes)
$logger = new Logger(
'messages',
diff --git a/src/opnsense/mvc/app/library/OPNsense/Firewall/Util.php b/src/opnsense/mvc/app/library/OPNsense/Firewall/Util.php
index 65db9b7b2..e1484940c 100644
--- a/src/opnsense/mvc/app/library/OPNsense/Firewall/Util.php
+++ b/src/opnsense/mvc/app/library/OPNsense/Firewall/Util.php
@@ -285,7 +285,7 @@ class Util
*/
public static function calcRuleHash($rule)
{
- // remove irrelavant fields
+ // remove irrelevant fields
foreach (array('updated', 'created', 'descr') as $key) {
unset($rule[$key]);
}
diff --git a/src/opnsense/mvc/app/library/OPNsense/Routing/Gateways.php b/src/opnsense/mvc/app/library/OPNsense/Routing/Gateways.php
index 036409d74..36960ad7d 100644
--- a/src/opnsense/mvc/app/library/OPNsense/Routing/Gateways.php
+++ b/src/opnsense/mvc/app/library/OPNsense/Routing/Gateways.php
@@ -290,7 +290,7 @@ class Gateways
/**
* determine default gateway, exclude gateways in skip list
- * since getGateways() is correcly ordered, we just need to find the first active, not down gateway
+ * since getGateways() is correctly ordered, we just need to find the first active, not down gateway
* @param array|null $skip list of gateways to ignore
* @param string $ipproto inet/inet6 type
* @return string type name
@@ -489,7 +489,7 @@ class Gateways
}
}
}
- // exit when tier has (a) usuable gateway(s)
+ // exit when tier has (a) usable gateway(s)
if (!empty($result[(string)$gw_group->name])) {
break;
}
diff --git a/src/opnsense/mvc/app/models/OPNsense/Base/BaseModel.php b/src/opnsense/mvc/app/models/OPNsense/Base/BaseModel.php
index a64479976..ba96fde04 100644
--- a/src/opnsense/mvc/app/models/OPNsense/Base/BaseModel.php
+++ b/src/opnsense/mvc/app/models/OPNsense/Base/BaseModel.php
@@ -645,7 +645,7 @@ abstract class BaseModel
if ($this->internal_mountpoint == ':memory:') {
return false;
} elseif (version_compare($this->internal_current_model_version, $this->internal_model_version, '<')) {
- $upgradePerfomed = false;
+ $upgradePerformed = false;
$migObjects = array();
$logger = new Logger(
'messages',
@@ -687,7 +687,7 @@ abstract class BaseModel
try {
$migobj->run($this);
$migObjects[] = $migobj;
- $upgradePerfomed = true;
+ $upgradePerformed = true;
} catch (Exception $e) {
$logger->error("failed migrating from version " .
$this->internal_current_model_version .
@@ -701,7 +701,7 @@ abstract class BaseModel
}
// serialize to config after last migration step, keep the config data static as long as not all
// migrations have completed.
- if ($upgradePerfomed) {
+ if ($upgradePerformed) {
try {
$this->serializeToConfig();
foreach ($migObjects as $migobj) {
diff --git a/src/opnsense/mvc/app/models/OPNsense/Base/Constraints/SetIfConstraint.php b/src/opnsense/mvc/app/models/OPNsense/Base/Constraints/SetIfConstraint.php
index 0d63cded9..01b74dc52 100644
--- a/src/opnsense/mvc/app/models/OPNsense/Base/Constraints/SetIfConstraint.php
+++ b/src/opnsense/mvc/app/models/OPNsense/Base/Constraints/SetIfConstraint.php
@@ -29,7 +29,7 @@
namespace OPNsense\Base\Constraints;
/**
- * validate if a field is set depening on the setting of another field
+ * validate if a field is set depending on the setting of another field
* containing a specific value
* Class SetIfConstraint
* @package OPNsense\Base\Constraints
diff --git a/src/opnsense/mvc/app/models/OPNsense/Base/FieldTypes/BaseField.php b/src/opnsense/mvc/app/models/OPNsense/Base/FieldTypes/BaseField.php
index 2e432c96d..b49d21e63 100644
--- a/src/opnsense/mvc/app/models/OPNsense/Base/FieldTypes/BaseField.php
+++ b/src/opnsense/mvc/app/models/OPNsense/Base/FieldTypes/BaseField.php
@@ -427,7 +427,7 @@ abstract class BaseField
}
/**
- * check for existance of child attribute
+ * check for existence of child attribute
* @return bool if child exists
*/
public function hasChild($name)
diff --git a/src/opnsense/mvc/app/models/OPNsense/Base/FieldTypes/LegacyLinkField.php b/src/opnsense/mvc/app/models/OPNsense/Base/FieldTypes/LegacyLinkField.php
index 56bbc7ee6..7e5a332b5 100644
--- a/src/opnsense/mvc/app/models/OPNsense/Base/FieldTypes/LegacyLinkField.php
+++ b/src/opnsense/mvc/app/models/OPNsense/Base/FieldTypes/LegacyLinkField.php
@@ -31,7 +31,7 @@ namespace OPNsense\Base\FieldTypes;
use OPNsense\Core\Config;
/**
- * Class LegacyLinkField field, read only referal to a config item in the legacy configuration.
+ * Class LegacyLinkField field, read only referral to a config item in the legacy configuration.
* @package OPNsense\Base\FieldTypes
*/
class LegacyLinkField extends BaseField
diff --git a/src/opnsense/mvc/app/models/OPNsense/Core/ACL/ACL.php b/src/opnsense/mvc/app/models/OPNsense/Core/ACL/ACL.php
index 8257172f0..e33295248 100644
--- a/src/opnsense/mvc/app/models/OPNsense/Core/ACL/ACL.php
+++ b/src/opnsense/mvc/app/models/OPNsense/Core/ACL/ACL.php
@@ -31,7 +31,7 @@
namespace OPNsense\Core\ACL;
/**
- * Class ACL, access control list wrappper
+ * Class ACL, access control list wrapper
* @package OPNsense\Core
*/
class ACL
diff --git a/src/opnsense/mvc/app/models/OPNsense/Firewall/Category.php b/src/opnsense/mvc/app/models/OPNsense/Firewall/Category.php
index 963ef97d9..87af08ab2 100644
--- a/src/opnsense/mvc/app/models/OPNsense/Firewall/Category.php
+++ b/src/opnsense/mvc/app/models/OPNsense/Firewall/Category.php
@@ -118,7 +118,7 @@ class Category extends BaseModel
/**
* collect unique categories from rules and updates the model with auto generated items.
- * XXX: if this operation turns out to be a bottleneck, we should move the maintance responsibiliy to the caller
+ * XXX: if this operation turns out to be a bottleneck, we should move the maintenance responsibility to the caller
* for the item in question (rule update)
* @return bool true if changed
*/
diff --git a/src/opnsense/mvc/app/models/OPNsense/Monit/Monit.php b/src/opnsense/mvc/app/models/OPNsense/Monit/Monit.php
index 607fd176c..79cb88786 100644
--- a/src/opnsense/mvc/app/models/OPNsense/Monit/Monit.php
+++ b/src/opnsense/mvc/app/models/OPNsense/Monit/Monit.php
@@ -45,11 +45,11 @@ class Monit extends BaseModel
'process' => ['Existence', 'ProcessResource', 'ProcessDiskIO',
'UID', 'GID', 'PID', 'PPID', 'Uptime', 'Connection', 'Custom'],
'file' => ['Existence', 'FileChecksum', 'Timestamp', 'FileSize',
- 'FileContent', 'Permisssion', 'UID', 'GID', 'Custom'],
- 'fifo' => ['Existence', 'Timestamp', 'Permisssion', 'UID', 'GID', 'Custom'],
+ 'FileContent', 'Permission', 'UID', 'GID', 'Custom'],
+ 'fifo' => ['Existence', 'Timestamp', 'Permission', 'UID', 'GID', 'Custom'],
'filesystem' => ['Existence', 'FilesystemMountFlags',
- 'SpaceUsage', 'InodeUsage', 'DiskIO', 'Permisssion', 'Custom'],
- 'directory' => ['Existence', 'Timestamp', 'Permisssion', 'UID', 'GID', 'Custom'],
+ 'SpaceUsage', 'InodeUsage', 'DiskIO', 'Permission', 'Custom'],
+ 'directory' => ['Existence', 'Timestamp', 'Permission', 'UID', 'GID', 'Custom'],
'host' => ['NetworkPing', 'Connection', 'Custom'],
'system' => ['SystemResource', 'Uptime', 'Custom'],
'custom' => ['ProgramStatus', 'Custom'],
@@ -104,7 +104,7 @@ class Monit extends BaseModel
'write rate',
'service time'
],
- 'Permisssion' => [
+ 'Permission' => [
'failed permission',
'changed permission'
],
@@ -201,7 +201,7 @@ class Monit extends BaseModel
$key
));
} else {
- // set the test tytpe according to the condition
+ // set the test type according to the condition
$parentNode->type = $type;
}
break;
diff --git a/src/opnsense/mvc/app/models/OPNsense/Monit/Monit.xml b/src/opnsense/mvc/app/models/OPNsense/Monit/Monit.xml
index 7c2a8e6ba..f9b11f13a 100644
--- a/src/opnsense/mvc/app/models/OPNsense/Monit/Monit.xml
+++ b/src/opnsense/mvc/app/models/OPNsense/Monit/Monit.xml
@@ -305,7 +305,7 @@
Space UsageInode UsageDisk I/O
- Permission
+ PermissionUIDGIDPID
diff --git a/src/opnsense/mvc/app/models/OPNsense/TrafficShaper/TrafficShaper.php b/src/opnsense/mvc/app/models/OPNsense/TrafficShaper/TrafficShaper.php
index 65cdb7efb..501e7f159 100644
--- a/src/opnsense/mvc/app/models/OPNsense/TrafficShaper/TrafficShaper.php
+++ b/src/opnsense/mvc/app/models/OPNsense/TrafficShaper/TrafficShaper.php
@@ -62,7 +62,7 @@ class TrafficShaper extends BaseModel
if ($currentval > $maximumval) {
$messages->appendMessage(new Message(
gettext(sprintf(
- "%d %s/s exceeds the maximum bandwith of %d %s/s.",
+ "%d %s/s exceeds the maximum bandwidth of %d %s/s.",
$currentval,
$parentNode->bandwidthMetric,
$maximumval,
diff --git a/src/opnsense/mvc/app/views/OPNsense/Diagnostics/log.volt b/src/opnsense/mvc/app/views/OPNsense/Diagnostics/log.volt
index 62e46f18f..dbb0d342d 100644
--- a/src/opnsense/mvc/app/views/OPNsense/Diagnostics/log.volt
+++ b/src/opnsense/mvc/app/views/OPNsense/Diagnostics/log.volt
@@ -68,7 +68,7 @@
requestHandler: function(request){
if ( $('#severity_filter').val().length > 0) {
let selectedSeverity = $('#severity_filter').val();
- // get selected severities or severeties below or equal to selected
+ // get selected severities or severities below or equal to selected
request['severity'] = filter_exact ? selectedSeverity : severities.slice(0,severities.indexOf(selectedSeverity) + 1);
}
return request;
diff --git a/src/opnsense/mvc/app/views/OPNsense/Diagnostics/netflow.volt b/src/opnsense/mvc/app/views/OPNsense/Diagnostics/netflow.volt
index 821e4c60b..aab7c37dc 100644
--- a/src/opnsense/mvc/app/views/OPNsense/Diagnostics/netflow.volt
+++ b/src/opnsense/mvc/app/views/OPNsense/Diagnostics/netflow.volt
@@ -89,7 +89,7 @@
{{ partial("layout_partials/base_form",['fields':captureForm,'id':'frm_CaptureSettings', 'apply_btn_id':'btn_save_capture'])}}
-
+
diff --git a/src/opnsense/mvc/app/views/OPNsense/Diagnostics/systemhealth.volt b/src/opnsense/mvc/app/views/OPNsense/Diagnostics/systemhealth.volt
index a8fdc563f..5fa8a880a 100644
--- a/src/opnsense/mvc/app/views/OPNsense/Diagnostics/systemhealth.volt
+++ b/src/opnsense/mvc/app/views/OPNsense/Diagnostics/systemhealth.volt
@@ -273,7 +273,7 @@
var stepsize = data["d3"]["stepSize"];
var scale = "{{ lang._('seconds') }}";
var dtformat = '%m/%d %H:%M';
- var visable_time=to-from;
+ var visible_time=to-from;
// set defaults based on stepsize
if (stepsize >= 86400) {
@@ -291,11 +291,11 @@
}
// if we have a focus area then change the x-scale to reflect current view
- if (visable_time >= (86400*7)) { // one week
+ if (visible_time >= (86400*7)) { // one week
dtformat = '\'%y w%U%';
- } else if (visable_time >= (3600*48)) { // 48 hours
+ } else if (visible_time >= (3600*48)) { // 48 hours
dtformat = '\'%y d%j%';
- } else if (visable_time >= (60*maxitems)) { // max minutes
+ } else if (visible_time >= (60*maxitems)) { // max minutes
dtformat = '%H:%M';
}
@@ -336,7 +336,7 @@
}
// Create tables (general and detail)
- if ($('input:radio[name=show_table]:checked').val() == 1) { // check if togle table is on
+ if ($('input:radio[name=show_table]:checked').val() == 1) { // check if toggle table is on
table_head = "
#
";
if ($('input:radio[name=toggle_time]:checked').val() == 1) {
table_head += "
{{ lang._('full date & time') }}
";
diff --git a/src/opnsense/mvc/app/views/OPNsense/Firewall/alias.volt b/src/opnsense/mvc/app/views/OPNsense/Firewall/alias.volt
index 05c04d230..b173ca8fd 100644
--- a/src/opnsense/mvc/app/views/OPNsense/Firewall/alias.volt
+++ b/src/opnsense/mvc/app/views/OPNsense/Firewall/alias.volt
@@ -247,7 +247,7 @@
break;
case 'urltable':
$("#row_alias\\.updatefreq").show();
- /* FALLTROUGH */
+ /* FALLTHROUGH */
default:
$("#alias_type_default").show();
$("#alias\\.proto").selectpicker('hide');
diff --git a/src/opnsense/mvc/app/views/OPNsense/Firewall/alias_util.volt b/src/opnsense/mvc/app/views/OPNsense/Firewall/alias_util.volt
index 0952d0333..ba3ed0ce1 100644
--- a/src/opnsense/mvc/app/views/OPNsense/Firewall/alias_util.volt
+++ b/src/opnsense/mvc/app/views/OPNsense/Firewall/alias_util.volt
@@ -103,7 +103,7 @@
}
}],
onshown: function(dialogRef) {
- // Remove all pre-existing event listeners, just to be sure.
+ // Remove all preexisting event listeners, just to be sure.
$('#ip-search').off();
$('#ip-search').on('click', function(event) {
if (!$("#ip-search > span").hasClass('fa-search')) {
diff --git a/src/opnsense/mvc/app/views/layouts/default.volt b/src/opnsense/mvc/app/views/layouts/default.volt
index 713758bed..50bee0aa0 100644
--- a/src/opnsense/mvc/app/views/layouts/default.volt
+++ b/src/opnsense/mvc/app/views/layouts/default.volt
@@ -174,7 +174,7 @@
-
+
diff --git a/src/opnsense/mvc/tests/app/models/OPNsense/Base/Constraints/ComparedToFieldConstraintTest.php b/src/opnsense/mvc/tests/app/models/OPNsense/Base/Constraints/ComparedToFieldConstraintTest.php
index 7db2ed0bb..dc17425b3 100644
--- a/src/opnsense/mvc/tests/app/models/OPNsense/Base/Constraints/ComparedToFieldConstraintTest.php
+++ b/src/opnsense/mvc/tests/app/models/OPNsense/Base/Constraints/ComparedToFieldConstraintTest.php
@@ -82,8 +82,8 @@ class ComparedToFieldConstraintTest extends \PHPUnit\Framework\TestCase
* @param $node_value integer field content
* @param $other_field_value integer field content
* @param $field string name of the field
- * @param $operator string see the related documentaton
- * @return ComparedToFieldConstraint the created contraint
+ * @param $operator string see the related documentation
+ * @return ComparedToFieldConstraint the created constraint
*/
private function make_validator($node_value, $other_field_value, $field, $operator)
{
diff --git a/src/opnsense/mvc/tests/app/models/OPNsense/Base/FieldTypes/ModelRelationFieldTest.php b/src/opnsense/mvc/tests/app/models/OPNsense/Base/FieldTypes/ModelRelationFieldTest.php
index 95db6da84..777dc6c37 100644
--- a/src/opnsense/mvc/tests/app/models/OPNsense/Base/FieldTypes/ModelRelationFieldTest.php
+++ b/src/opnsense/mvc/tests/app/models/OPNsense/Base/FieldTypes/ModelRelationFieldTest.php
@@ -209,7 +209,7 @@ class ModelRelationFieldTest extends Field_Framework_TestCase
}
/**
- * Selecting none option, while blank desciption override.
+ * Selecting none option, while blank description override.
* Defined blank description should pass through to value, and show selected.
* Needs not required (default), and multiple false (default)
*/
@@ -231,7 +231,7 @@ class ModelRelationFieldTest extends Field_Framework_TestCase
}
/**
- * Selecting none option, while blank desciption override.
+ * Selecting none option, while blank description override.
* Empty Blank description should get override with word "none"
* Needs not required (default), and multiple false (default)
*/
diff --git a/src/opnsense/scripts/OPNsense/CaptivePortal/cp-background-process.py b/src/opnsense/scripts/OPNsense/CaptivePortal/cp-background-process.py
index c7a7e8bbe..a26db4f7c 100755
--- a/src/opnsense/scripts/OPNsense/CaptivePortal/cp-background-process.py
+++ b/src/opnsense/scripts/OPNsense/CaptivePortal/cp-background-process.py
@@ -83,7 +83,7 @@ class CPBackgroundProcess(object):
self.db.del_client(zoneid, session['sessionId'])
if sessions_deleted == len(sessions) or len(sessions) == 0:
# when there's no session active, add a new one
- # (only administrative, the sync process will add it if neccesary)
+ # (only administrative, the sync process will add it if necessary)
if ip_address is not None:
self.db.add_client(zoneid, "---ip---", "", ip_address, "")
else:
@@ -227,7 +227,7 @@ def main():
capture_output=True
)
except OSError:
- # if accounting script crashes don't exit backgroung process
+ # if accounting script crashes don't exit background process
pass
# sleep
diff --git a/src/opnsense/scripts/OPNsense/CaptivePortal/lib/__init__.py b/src/opnsense/scripts/OPNsense/CaptivePortal/lib/__init__.py
index 3eda8827e..82db6c135 100755
--- a/src/opnsense/scripts/OPNsense/CaptivePortal/lib/__init__.py
+++ b/src/opnsense/scripts/OPNsense/CaptivePortal/lib/__init__.py
@@ -36,7 +36,7 @@ class Config(object):
_cnf_filename = "/usr/local/etc/captiveportal.conf"
def __init__(self):
- """ consctruct new config object
+ """ construct new config object
"""
self.last_updated = 0
self._conf_handle = None
diff --git a/src/opnsense/scripts/OPNsense/CaptivePortal/lib/ipfw.py b/src/opnsense/scripts/OPNsense/CaptivePortal/lib/ipfw.py
index b35a2e46c..b7413c9f6 100755
--- a/src/opnsense/scripts/OPNsense/CaptivePortal/lib/ipfw.py
+++ b/src/opnsense/scripts/OPNsense/CaptivePortal/lib/ipfw.py
@@ -95,7 +95,7 @@ class IPFW(object):
@staticmethod
def list_accounting_info():
- """ list accounting info per ip addres, addresses can't overlap in zone's so we just output all we know here
+ """ list accounting info per ip address, addresses can't overlap in zone's so we just output all we know here
instead of trying to map addresses back to zones.
:return: list accounting info per ip address
"""
diff --git a/src/opnsense/scripts/dhcp/dnsmasq_watcher.py b/src/opnsense/scripts/dhcp/dnsmasq_watcher.py
index 19dd2eb9b..afb9d56f9 100755
--- a/src/opnsense/scripts/dhcp/dnsmasq_watcher.py
+++ b/src/opnsense/scripts/dhcp/dnsmasq_watcher.py
@@ -97,7 +97,7 @@ def run_watcher(target_filename, default_domain, watch_file, service_pid):
if __name__ == '__main__':
parser = argparse.ArgumentParser()
parser.add_argument('--domain', help='default domain to use', default='local')
- parser.add_argument('--foreground', help='run in forground', default=False, action='store_true')
+ parser.add_argument('--foreground', help='run in foreground', default=False, action='store_true')
parser.add_argument('--pid', help='pid file location', default='/var/run/dnsmasq_dhcpd.pid')
parser.add_argument('--servicepid', help='dnsmasq pid file location', default='/var/run/dnsmasq.pid')
parser.add_argument('--source', help='source leases file', default='/var/dhcpd/var/db/dhcpd.leases')
diff --git a/src/opnsense/scripts/dhcp/unbound_watcher.py b/src/opnsense/scripts/dhcp/unbound_watcher.py
index 17933eb50..7e187baad 100755
--- a/src/opnsense/scripts/dhcp/unbound_watcher.py
+++ b/src/opnsense/scripts/dhcp/unbound_watcher.py
@@ -210,7 +210,7 @@ if __name__ == '__main__':
default='/var/dhcpd/var/db/dhcpd.leases')
parser.add_argument('--target', help='target config file, used when unbound restarts',
default='/var/unbound/dhcpleases.conf')
- parser.add_argument('--foreground', help='run in forground', default=False, action='store_true')
+ parser.add_argument('--foreground', help='run in foreground', default=False, action='store_true')
parser.add_argument('--domain', help='default domain to use', default='local')
parser.add_argument('--config', help='configuration file to use', default='/usr/local/etc/unbound_dhcpd.conf')
diff --git a/src/opnsense/scripts/filter/read_log.py b/src/opnsense/scripts/filter/read_log.py
index 10d6431eb..d2a1f67c7 100755
--- a/src/opnsense/scripts/filter/read_log.py
+++ b/src/opnsense/scripts/filter/read_log.py
@@ -170,7 +170,7 @@ if __name__ == '__main__':
# no id for translation rules
rule['label'] = "%s rule" % rule['action']
elif len(rulep) > 0 and len(rulep[-1]) == 32 and set(rulep[-1]).issubset(HEX_DIGITS):
- # rule id apended in record format, don't use rule sequence number in that case either
+ # rule id appended in record format, don't use rule sequence number in that case either
rule['rid'] = rulep[-1]
if rulep[-1] in running_conf_descr:
rule['label'] = running_conf_descr[rulep[-1]]
diff --git a/src/opnsense/scripts/firmware/check.sh b/src/opnsense/scripts/firmware/check.sh
index 0fe6f6833..76b9995d1 100755
--- a/src/opnsense/scripts/firmware/check.sh
+++ b/src/opnsense/scripts/firmware/check.sh
@@ -29,7 +29,7 @@
#
# connection: error|unauthenticated|misconfigured|unresolved|ok
# repository: error|untrusted|unsigned|revoked|incomplete|forbidden|ok
-# last_ckeck:
+# last_check:
# download_size: [,]
# new_packages: array with { name: , version: }
# reinstall_packages: array with { name: , version: }
diff --git a/src/opnsense/scripts/interfaces/mpd.script b/src/opnsense/scripts/interfaces/mpd.script
index da2254361..8ac41ddbc 100755
--- a/src/opnsense/scripts/interfaces/mpd.script
+++ b/src/opnsense/scripts/interfaces/mpd.script
@@ -75,7 +75,7 @@
## (3Com Impact IQ only)
##
## We set $OptimizeNextTime to "yes" after a successful connection so we
-## can avoid verifing configuration when things are working good.
+## can avoid verifying configuration when things are working good.
##
## Internal variables:
##
@@ -992,7 +992,7 @@ ImpactIQCheckDirnos:
if $TA_Bonding == "yes" set $checkValue "001"
if $TA_Bonding == "yes" set $checkValueNew "1"
set $checkCmd "S80"
- set $checkMsg "Reprogramming mutli-link PPP setting..."
+ set $checkMsg "Reprogramming multi-link PPP setting..."
call ModemCheckValue
# Restart if necessary, and wait extra long if the switch type changed
@@ -1185,7 +1185,7 @@ AdtranXRTDialError:
failure
##
-## Check the last status bufffer entry for what the problem is
+## Check the last status buffer entry for what the problem is
## XXX Figure out more stuff to look for and when it can happen
##
diff --git a/src/opnsense/scripts/interfaces/traffic_top.py b/src/opnsense/scripts/interfaces/traffic_top.py
index f856fd11c..a248b4c9b 100755
--- a/src/opnsense/scripts/interfaces/traffic_top.py
+++ b/src/opnsense/scripts/interfaces/traffic_top.py
@@ -91,8 +91,8 @@ class AsyncLookup:
dnsResolver = Resolver()
dnsResolver.timeout = 2
tasks = []
- for adres in addresses:
- tasks.append(dnsResolver.resolve_address(adres))
+ for address in addresses:
+ tasks.append(dnsResolver.resolve_address(address))
responses = await asyncio.gather(*tasks, return_exceptions=True)
for response in responses:
if type(response) is dns.resolver.Answer:
diff --git a/src/opnsense/scripts/netflow/lib/aggregates/__init__.py b/src/opnsense/scripts/netflow/lib/aggregates/__init__.py
index 8d8e2bf62..da4c6d707 100755
--- a/src/opnsense/scripts/netflow/lib/aggregates/__init__.py
+++ b/src/opnsense/scripts/netflow/lib/aggregates/__init__.py
@@ -106,7 +106,7 @@ class BaseFlowAggregator(object):
cur.close()
def _create_target_table(self):
- """ construct target aggregate table, using resulution and list of agg_fields
+ """ construct target aggregate table, using resolution and list of agg_fields
:return: None
"""
if self._db_connection is not None:
diff --git a/src/opnsense/scripts/netflow/lib/aggregates/interface.py b/src/opnsense/scripts/netflow/lib/aggregates/interface.py
index 77213fe9a..b7bdb5fd6 100755
--- a/src/opnsense/scripts/netflow/lib/aggregates/interface.py
+++ b/src/opnsense/scripts/netflow/lib/aggregates/interface.py
@@ -57,7 +57,7 @@ class FlowInterfaceTotals(BaseFlowAggregator):
def __init__(self, resolution, database_dir='/var/netflow'):
"""
- :param resolution: sample resultion (seconds)
+ :param resolution: sample resolution (seconds)
:return: None
"""
super(FlowInterfaceTotals, self).__init__(resolution, database_dir)
diff --git a/src/opnsense/scripts/netflow/lib/aggregates/ports.py b/src/opnsense/scripts/netflow/lib/aggregates/ports.py
index 4e1e7fa94..32b5a2da4 100755
--- a/src/opnsense/scripts/netflow/lib/aggregates/ports.py
+++ b/src/opnsense/scripts/netflow/lib/aggregates/ports.py
@@ -57,7 +57,7 @@ class FlowDstPortTotals(BaseFlowAggregator):
def __init__(self, resolution, database_dir='/var/netflow'):
"""
- :param resolution: sample resultion (seconds)
+ :param resolution: sample resolution (seconds)
:return: None
"""
super(FlowDstPortTotals, self).__init__(resolution, database_dir)
diff --git a/src/opnsense/scripts/netflow/lib/aggregates/source.py b/src/opnsense/scripts/netflow/lib/aggregates/source.py
index b39752870..f68b8a3ce 100755
--- a/src/opnsense/scripts/netflow/lib/aggregates/source.py
+++ b/src/opnsense/scripts/netflow/lib/aggregates/source.py
@@ -57,7 +57,7 @@ class FlowSourceAddrTotals(BaseFlowAggregator):
def __init__(self, resolution, database_dir='/var/netflow'):
"""
- :param resolution: sample resultion (seconds)
+ :param resolution: sample resolution (seconds)
:return: None
"""
super(FlowSourceAddrTotals, self).__init__(resolution, database_dir)
diff --git a/src/opnsense/scripts/proxy/fetchACLs.py b/src/opnsense/scripts/proxy/fetchACLs.py
index 8e5c18307..af5923997 100755
--- a/src/opnsense/scripts/proxy/fetchACLs.py
+++ b/src/opnsense/scripts/proxy/fetchACLs.py
@@ -272,7 +272,7 @@ class DomainSorter(object):
def filename_in_ignorelist(bfilename, filename_ext):
""" ignore certain files from processing.
:param bfilename: basefilename to inspect
- :param filename_ext: extention of the filename
+ :param filename_ext: extension of the filename
"""
if filename_ext in ['pdf', 'txt', 'doc']:
return True
diff --git a/src/opnsense/scripts/shell/firmware.sh b/src/opnsense/scripts/shell/firmware.sh
index 75d2ed906..f602a132e 100755
--- a/src/opnsense/scripts/shell/firmware.sh
+++ b/src/opnsense/scripts/shell/firmware.sh
@@ -27,7 +27,7 @@
set -e
-# From this shell script never execute any remote work priror to user
+# From this shell script never execute any remote work prior to user
# consent. The first action is the unconditional changelog fetch after
# script invoke. After that we opportunistically run the selected major
# "upgrade"/minor "update" request as it appears to be available.
diff --git a/src/opnsense/scripts/suricata/installRules.py b/src/opnsense/scripts/suricata/installRules.py
index 68e18e0e1..75ec55a3b 100755
--- a/src/opnsense/scripts/suricata/installRules.py
+++ b/src/opnsense/scripts/suricata/installRules.py
@@ -55,7 +55,7 @@ if __name__ == '__main__':
for rule_info_record in RuleCache.list_rules(filename=filename):
# default behavior, do not touch rule, only copy to output
rule = rule_info_record['rule']
- # change rule if in rule rule updates
+ # change rule if in rule updates
if rule_info_record['metadata'] is not None and 'sid' in rule_info_record['metadata'] \
and rule_info_record['metadata']['sid'] in rule_updates:
# search last comment marker
diff --git a/src/opnsense/scripts/suricata/lib/rulecache.py b/src/opnsense/scripts/suricata/lib/rulecache.py
index 9022d71bb..c5edc2518 100755
--- a/src/opnsense/scripts/suricata/lib/rulecache.py
+++ b/src/opnsense/scripts/suricata/lib/rulecache.py
@@ -225,7 +225,7 @@ class RuleCache(object):
if last_mtime == results[0][0] and len(all_rule_files) == results[0][1] and table_count == 5:
return False
except sqlite3.DatabaseError:
- # if some reason the cache is unreadble, continue and report changed
+ # if some reason the cache is unreadable, continue and report changed
pass
return True
diff --git a/src/opnsense/service/modules/addons/template_helpers.py b/src/opnsense/service/modules/addons/template_helpers.py
index c886563da..87a8de491 100644
--- a/src/opnsense/service/modules/addons/template_helpers.py
+++ b/src/opnsense/service/modules/addons/template_helpers.py
@@ -115,7 +115,7 @@ class Helpers(object):
a list. The configuration doesn't know if a non repeating item is supposed to be a list of items, this makes
it explicit.
:param tag: tag in dot notation (section.item)
- :param sortBy: resort result by specfied key
+ :param sortBy: resort result by specified key
:return: []
"""
result = self.getNodeByTag(tag)
diff --git a/src/opnsense/service/modules/template.py b/src/opnsense/service/modules/template.py
index 242872297..9ee0a0327 100644
--- a/src/opnsense/service/modules/template.py
+++ b/src/opnsense/service/modules/template.py
@@ -303,7 +303,7 @@ class Template(object):
def iter_modules(self, module_name):
"""
:param module_name: module name in dot notation ( company.module ), may use wildcards
- :return: templates matching paterns
+ :return: templates matching patterns
"""
for template_name in sorted(self.list_modules()):
wildcard_pos = module_name.find('*')
diff --git a/src/opnsense/service/templates/OPNsense/Captiveportal/lighttpd-api-dispatcher.conf b/src/opnsense/service/templates/OPNsense/Captiveportal/lighttpd-api-dispatcher.conf
index 8ed4a87b8..79e89d867 100644
--- a/src/opnsense/service/templates/OPNsense/Captiveportal/lighttpd-api-dispatcher.conf
+++ b/src/opnsense/service/templates/OPNsense/Captiveportal/lighttpd-api-dispatcher.conf
@@ -34,7 +34,7 @@ server.indexfiles = ( "index.php", "index.html",
url.access-deny = ( "~", ".inc" )
-######### Options that are good to be but not neccesary to be changed #######
+######### Options that are good to be but not necessary to be changed #######
## bind to port (default: 80)
server.bind = "127.0.0.1"
diff --git a/src/opnsense/service/templates/OPNsense/IDS/suricata.yaml b/src/opnsense/service/templates/OPNsense/IDS/suricata.yaml
index 96b9970a0..79d92670a 100644
--- a/src/opnsense/service/templates/OPNsense/IDS/suricata.yaml
+++ b/src/opnsense/service/templates/OPNsense/IDS/suricata.yaml
@@ -444,7 +444,7 @@ outputs:
- syslog:
enabled: {% if helpers.empty('OPNsense.IDS.general.syslog') %}no{% else %}yes{% endif %}
- # reported identity to syslog. If ommited the program name (usually
+ # reported identity to syslog. If omitted the program name (usually
# suricata) will be used.
#identity: "suricata"
facility: local5
@@ -855,7 +855,7 @@ app-layer:
# server-config: List of server configurations to use if address matches
# address: List of IP addresses or networks for this block
- # personalitiy: List of personalities used by this block
+ # personality: List of personalities used by this block
#
# Then, all the fields from default-config can be overloaded
#
@@ -903,7 +903,7 @@ app-layer:
# detection change between runs. It is set to 'yes' by default.
#randomize-inspection-sizes: yes
# If randomize-inspection-sizes is active, the value of various
- # inspection size will be choosen in the [1 - range%, 1 + range%]
+ # inspection size will be chosen in the [1 - range%, 1 + range%]
# range
# Default value of randomize-inspection-range is 10.
#randomize-inspection-range: 10
@@ -1491,7 +1491,7 @@ threading:
- worker-cpu-set:
cpu: [ "all" ]
mode: "exclusive"
- # Use explicitely 3 threads and don't compute number by using
+ # Use explicitly 3 threads and don't compute number by using
# detect-thread-ratio variable:
# threads: 3
prio:
@@ -1618,7 +1618,7 @@ profiling:
# accept the packet if Suricata is not able to keep pace.
# bypass mark and mask can be used to implement NFQ bypass. If bypass mark is
# set then the NFQ bypass is activated. Suricata will set the bypass mark/mask
-# on packet of a flow that need to be bypassed. The Nefilter ruleset has to
+# on packet of a flow that need to be bypassed. The Netfilter ruleset has to
# directly accept all packets of a flow once a packet has been marked.
nfq:
# mode: accept
diff --git a/src/opnsense/service/templates/OPNsense/Proxy/squid.conf b/src/opnsense/service/templates/OPNsense/Proxy/squid.conf
index 212523677..d91e0c618 100644
--- a/src/opnsense/service/templates/OPNsense/Proxy/squid.conf
+++ b/src/opnsense/service/templates/OPNsense/Proxy/squid.conf
@@ -414,7 +414,7 @@ via off
{% endif %}
{% if helpers.exists('OPNsense.proxy.general.suppressVersion') %}
{% if OPNsense.proxy.general.suppressVersion == '1' %}
-# Suppres http version string (default=off)
+# Suppress http version string (default=off)
httpd_suppress_version_string on
{% endif %}
{% endif %}
@@ -424,7 +424,7 @@ icp_port {{OPNsense.proxy.general.icpPort}}
{% endif %}
{% endif %}
{% if helpers.exists('OPNsense.proxy.general.uriWhitespaceHandling') %}
-# URI hanlding with Whitespaces (default=strip)
+# URI handling with Whitespaces (default=strip)
uri_whitespace {{OPNsense.proxy.general.uriWhitespaceHandling}}
{% endif %}
{% if helpers.exists('OPNsense.proxy.general.forwardedForHandling') %}
@@ -445,7 +445,7 @@ delay_pools 1
delay_class 1 3
delay_access 1 allow all
{% if helpers.exists('OPNsense.proxy.general.traffic.OverallBandwidthTrotteling') %}
-# Define PerHost and Overall Bandwith Trotteling
+# Define PerHost and Overall Bandwidth Trotteling
delay_parameters 1 {{OPNsense.proxy.general.traffic.OverallBandwidthTrotteling|int // 8 * 1000}}/{{OPNsense.proxy.general.traffic.OverallBandwidthTrotteling|int // 8 * 1000}} -1/-1 {{OPNsense.proxy.general.traffic.perHostTrotteling|int // 8 * 1000}}/{{OPNsense.proxy.general.traffic.OverallBandwidthTrotteling|int // 8 * 1000}}
{% else %}
# Define PerHost Trotteling
diff --git a/src/opnsense/www/api.php b/src/opnsense/www/api.php
index 6f6eaf78e..f614e4cd1 100644
--- a/src/opnsense/www/api.php
+++ b/src/opnsense/www/api.php
@@ -32,7 +32,7 @@ try {
if (method_exists($e, 'getTitle')) {
$response['errorTitle'] = $e->getTitle();
} else {
- $response['errorTitle'] = gettext('An API exception occured');
+ $response['errorTitle'] = gettext('An API exception occurred');
$response['errorMessage'] = $e->getFile() . ':' . $e->getLine() . ': ' . $response['errorMessage'];
error_log($e);
}
diff --git a/src/opnsense/www/js/opnsense.js b/src/opnsense/www/js/opnsense.js
index 844a7d6c9..dae02ecc5 100644
--- a/src/opnsense/www/js/opnsense.js
+++ b/src/opnsense/www/js/opnsense.js
@@ -254,7 +254,7 @@ function ajaxGet(url,sendData,callback) {
*/
function watchScrollPosition() {
function current_location() {
- // concat url pieces to indentify this page and parameters
+ // concat url pieces to identify this page and parameters
return window.location.href.replace(/\/|\:|\.|\?|\#/gi, '');
}
diff --git a/src/opnsense/www/themes/opnsense/assets/stylesheets/bootstrap/_input-groups.scss b/src/opnsense/www/themes/opnsense/assets/stylesheets/bootstrap/_input-groups.scss
index ae0e921bf..f56322e3b 100644
--- a/src/opnsense/www/themes/opnsense/assets/stylesheets/bootstrap/_input-groups.scss
+++ b/src/opnsense/www/themes/opnsense/assets/stylesheets/bootstrap/_input-groups.scss
@@ -135,7 +135,7 @@
font-size: 0;
white-space: nowrap;
- // Negative margin for spacing, position for bringing hovered/focused/actived
+ // Negative margin for spacing, position for bringing hovered/focused/activated
// element above the siblings.
> .btn {
position: relative;
diff --git a/src/opnsense/www/themes/opnsense/assets/stylesheets/bootstrap/mixins/_hide-text.scss b/src/opnsense/www/themes/opnsense/assets/stylesheets/bootstrap/mixins/_hide-text.scss
index 5e0697218..c5a281ffa 100644
--- a/src/opnsense/www/themes/opnsense/assets/stylesheets/bootstrap/mixins/_hide-text.scss
+++ b/src/opnsense/www/themes/opnsense/assets/stylesheets/bootstrap/mixins/_hide-text.scss
@@ -1,6 +1,6 @@
// CSS image replacement
//
-// Heads up! v3 launched with with only `.hide-text()`, but per our pattern for
+// Heads up! v3 launched with only `.hide-text()`, but per our pattern for
// mixins being reused as classes with the same name, this doesn't hold up. As
// of v3.0.1 we have added `.text-hide()` and deprecated `.hide-text()`.
//
diff --git a/src/sbin/ping_hosts.sh b/src/sbin/ping_hosts.sh
index 6751fdbb5..06343e8b8 100755
--- a/src/sbin/ping_hosts.sh
+++ b/src/sbin/ping_hosts.sh
@@ -3,7 +3,7 @@
# Copyright (c) 2006 Scott Ullrich
# All rights reserved.
-# Format of file should be deliminted by |
+# Format of file should be delimited by |
# Field 1: Source ip
# Field 2: Destination ip
# Field 3: Ping count
diff --git a/src/wizard/system.xml b/src/wizard/system.xml
index eb852edbd..7209de45f 100644
--- a/src/wizard/system.xml
+++ b/src/wizard/system.xml
@@ -452,7 +452,7 @@ if (!empty($_POST['pptplocalipaddress']) && !is_ipaddr($_POST['pptplocalipaddres
$input_errors[] = gettext('Invalid PPTP Local IP address.');
}
if (!empty($_POST['pptpremoteipaddress']) && !is_ipaddr($_POST['pptpremoteipaddress'])) {
- $input_errors[] = gettext('Invalid PPTP Remopte IP address.');
+ $input_errors[] = gettext('Invalid PPTP Remote IP address.');
}
if (!empty($input_errors)) {
$stepid--;
diff --git a/src/www/firewall_schedule_edit.php b/src/www/firewall_schedule_edit.php
index 807d1635d..3be5db280 100644
--- a/src/www/firewall_schedule_edit.php
+++ b/src/www/firewall_schedule_edit.php
@@ -370,7 +370,7 @@ function checkForRanges(){
function processEntries(){
var tempstr, starttimehour, starttimemin, stoptimehour, stoptimemin, errors = "";
- var passedValidiation = true;
+ var passedValidation = true;
//get time specified
starttimehour = parseInt(document.getElementById("starttimehour").value);
@@ -383,18 +383,18 @@ function processEntries(){
if (starttimehour > stoptimehour)
{
errors = "Error: Start Hour cannot be greater than Stop Hour.";
- passedValidiation = false;
+ passedValidation = false;
}
else if (starttimehour == stoptimehour)
{
if (starttimemin > stoptimemin){
errors = "Error: Start Minute cannot be greater than Stop Minute.";
- passedValidiation = false;
+ passedValidation = false;
}
}
- if (passedValidiation){
+ if (passedValidation){
addTimeRange();
}
else {
diff --git a/src/www/guiconfig.inc b/src/www/guiconfig.inc
index 7c07e247a..5fc03efbd 100644
--- a/src/www/guiconfig.inc
+++ b/src/www/guiconfig.inc
@@ -86,7 +86,7 @@ function get_themed_filename($url)
require_once("authgui.inc");
-/* Reserved table names to avoid colision */
+/* Reserved table names to avoid collision */
$reserved_table_names = [
'bogons',
'bogonsv6',
@@ -283,7 +283,7 @@ function get_std_save_message($plain = false)
}
return sprintf(
gettext("The changes have been applied successfully, ".
- "remember to update your backup server in %sSystem: High availablity: status%s"),
+ "remember to update your backup server in %sSystem: High availability: status%s"),
$lnk_start, $lnk_end
);
} else {
diff --git a/src/www/interfaces.php b/src/www/interfaces.php
index b7d0e1d05..bb8a4c197 100644
--- a/src/www/interfaces.php
+++ b/src/www/interfaces.php
@@ -562,7 +562,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
$input_errors = array();
if (!empty($_POST['if']) && !empty($a_interfaces[$_POST['if']])) {
$if = $_POST['if'];
- // read physcial interface name from config.xml
+ // read physical interface name from config.xml
$pconfig['if'] = $a_interfaces[$if]['if'];
}
$ifgroup = !empty($_GET['group']) ? $_GET['group'] : '';
@@ -926,7 +926,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
}
do_input_validation($pconfig, $reqdfields, $reqdfieldsn, $input_errors);
- // check_wireless_mode (more wireless weirness)
+ // check_wireless_mode (more wireless weirdness)
// validations shouldn't perform actual actions, needs serious fixing at some point
if ($a_interfaces[$if]['wireless']['mode'] != $pconfig['mode']) {
if (does_interface_exist(interface_get_wireless_clone($wlanbaseif))) {
@@ -1308,7 +1308,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
}
// todo: it's probably better to choose one place to store wireless data
- // this construction implements a lot of weirness (more info interface_sync_wireless_clones)
+ // this construction implements a lot of weirdness (more info interface_sync_wireless_clones)
$wlanbaseif = interface_get_wireless_base($a_interfaces[$if]['if']);
if (!empty($pconfig['persistcommonwireless'])) {
config_read_array('wireless', 'interfaces', $wlanbaseif);
@@ -2026,7 +2026,7 @@ include("head.inc");
-
=gettext("Overwite global settings"); ?>
+
=gettext("Overwrite global settings"); ?>
/>
diff --git a/src/www/javascript/opnsense_legacy.js b/src/www/javascript/opnsense_legacy.js
index 1f7611c72..e2aaefba8 100644
--- a/src/www/javascript/opnsense_legacy.js
+++ b/src/www/javascript/opnsense_legacy.js
@@ -182,7 +182,7 @@ function window_highlight_table_option()
/**
- * load fireall categories and hook change events.
+ * load firewall categories and hook change events.
* in order to use this partial the html template should contain the following:
* - a
diff --git a/src/opnsense/mvc/app/models/OPNsense/Base/Constraints/ComparedToFieldConstraint.php b/src/opnsense/mvc/app/models/OPNsense/Base/Constraints/ComparedToFieldConstraint.php
index c8d91d555..dc25cc02c 100644
--- a/src/opnsense/mvc/app/models/OPNsense/Base/Constraints/ComparedToFieldConstraint.php
+++ b/src/opnsense/mvc/app/models/OPNsense/Base/Constraints/ComparedToFieldConstraint.php
@@ -67,7 +67,7 @@ class ComparedToFieldConstraint extends BaseConstraint
}
if (
- !$this->is_contraint_fulfilled(
+ !$this->is_constraint_fulfilled(
$operator,
floatval((string)$node),
floatval((string)$other_node_content)
@@ -83,9 +83,9 @@ class ComparedToFieldConstraint extends BaseConstraint
* @param $operator string one of gt|gte|lt|lte|eq|neq
* @param $our_value float the value of this field
* @param $foreign_value float the value of the referenced field
* @return bool if the contraint is fulfilled
*/
- private function is_contraint_fulfilled($operator, $our_value, $foreign_value)
+ private function is_constraint_fulfilled($operator, $our_value, $foreign_value)
{
switch ($operator) {
case 'gt':
@@ -83,9 +83,9 @@ class ComparedToFieldConstraint extends BaseConstraint
* @param $our_value float the value of this field
* @param $foreign_value float the value of the referenced field
- * @return bool if the contraint is fulfilled
+ * @return bool if the constraint is fulfilled
*/